@@ -42,9 +42,11 @@ ENGLISH_PATTERNS = [
     "ക്ട്$",
     "ക്യൂ",
     "ക്സ",
+    "ക്ലോ",
     "ക്റ്റ്",
     "ഗ്രഫ",
     "ഗ്രഫി",
+    "ഗിൾ",
     "ങ്സ്",
     "ച്വ",
     "ജ്യു",
@@ -155,7 +157,8 @@ ENGLISH_PATTERNS = [
     "ോഷൻ",
     "ൗണ്ട",
     "്രീം",
-    "ക്വേ"
+    "ക്വേ",
+    "[0-9]+"
 ]
 
 compiled_english_pattern_regex = re.compile("|".join(ENGLISH_PATTERNS))
