@@ -1,14 +1,13 @@
 #!/usr/bin/env python
 
 """
-Simple python interface for mlmorph using libhfst-python.
+Simple python interface for mlmorph using sfst
 """
 
-from libhfst import HfstTransducer
+import sfst
 from pkg_resources import resource_filename, resource_exists
 from typing import Tuple
 from .normalizer import normalize
-from .utils import get_transducer
 from .analyser import Analyser
 
 
@@ -22,8 +21,7 @@ class Generator:
             self.fsa = resource_filename(__name__, Generator.RESOURCE_PATH)
         if not self.fsa:
             raise ValueError('Could not read the fsa.')
-        self.transducer: HfstTransducer = None
-        self.generator: HfstTransducer = None
+        sfst.init(self.fsa)
 
     @staticmethod
     def get_weight(generated_word: str, token: str) -> int:
@@ -45,27 +43,16 @@ class Generator:
 
     def generate(self, token: str, weighted: bool = True) -> Tuple:
         """Perform a simple morphological generator lookup."""
-        if not self.generator:
-            self.generator = self.get_generator()
-
         token = normalize(token)
-        generated_results = self.generator.lookup(token)
+        generated_results = sfst.generate(token)
         if not weighted:
             return generated_results
 
         processed_result = []
         for gindex in range(len(generated_results)):
             generated_result_weight = Generator.get_weight(
-                generated_results[gindex][0], token)
+                generated_results[gindex], token)
             processed_result.append(
-                (generated_results[gindex][0], generated_result_weight))
+                (generated_results[gindex], generated_result_weight))
         return sorted(processed_result, key=lambda tup: tup[1])
 
-    def get_generator(self) -> HfstTransducer:
-        if not self.transducer:
-            self.transducer = get_transducer(self.fsa)
-        generator = HfstTransducer(self.transducer)
-        generator.remove_epsilons()
-        generator.lookup_optimize()
-        return generator
-
